#!/bin/bash

# transfer-monitor-report.sh
# Generates hourly, daily or weekly  reports.


usage="transfer-monitor-report.sh [ -f <configfile> ] -c <report_category> -t <report_type> -i <interval>"

# Default Values from Configuration File.
REPORTS_INSTALLDIR=/opt/glite
REPORTS_OUT_DIR=/opt/glite/var/transfer-monitor-report/xml
REPORTS_HTML_DIR=/opt/glite/var/transfer-monitor-report/www
REPORTS_HTML_WEBROOT_PATH=/transfer-monitor-report
ORACLE_LOCATION=/usr/lib/oracle/10.2.0.1

# Read in and check the configuration.
CONFIG=/opt/glite/etc/transfer-monitor-report.conf

while getopts "f:c:t:i:h" options ; do
   case $options in 
      h) echo $usage
         exit ;;
      f) CONFIG=$OPTARG;;
      c) REPORT_CATEGORY=$OPTARG;;
      t) REPORT_TYPE=$OPTARG;;
      i) REPORT_INTERVAL=$OPTARG;;
      *) echo $usage
         exit 1;;
   esac
done

# Check the values.
if [ "$REPORT_CATEGORY" != "channel" ] ; then
    echo "The report category $REPORT_CATEGORY is not acceptable"
    echo "The only category currently is channel"
    echo $usage
    exit 1;
fi

if [ "$REPORT_TYPE" != "file" ] && [ "$REPORT_TYPE" != "transfer" ] ; then
    echo "The report type $REPORT_TYPE is not acceptable"
    echo "The only types are currently file or transfer"
    echo $usage
    exit 1;

fi

if [ "$REPORT_INTERVAL" != "day" ] && [ "$REPORT_INTERVAL" != "hour" ] && [ "$REPORT_INTERVAL" != "week" ] ; then
    echo "The report interval $REPORT_INTERVAL is not acceptable"
    echo "The only intervals are currently hour, day or week"
    echo $usage
    exit 1;

fi

# Read in the configuration.
if [ ! -r $CONFIG ] ; then
    echo "Config file $CONFIG does not readable"
    exit 1;
else
    . $CONFIG
fi

if [ $REPORT_INTERVAL = "hour" ] ; then
     REPORT_REL_DIR=`date +'%Y/%m/%d'`
elif [ $REPORT_INTERVAL = "day" ] ; then
     REPORT_REL_DIR=`date +'%Y/%m'` 
elif [ $REPORT_INTERVAL = "week" ] ; then
     REPORT_REL_DIR=`date +'%Y'`
fi

# Check output directories can be written to.
for D in $REPORTS_OUT_DIR $REPORTS_HTML_DIR
do
    if [ ! -w $D ] || [ ! -d $D ] ; then
      echo "$D is not a writable directory"
      exit 1 ;
    fi
done


. $REPORTS_INSTALLDIR/libexec/transfer-monitor-report-common.sh

# Generate report
make_report

# Generate html
make_html







